package com.ruoyi.jjh.declaration.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.jjh.declaration.entity.BmsBigStrongAward;
import com.ruoyi.jjh.declaration.entity.BmsBrandingAward;
import com.ruoyi.jjh.declaration.entity.BmsDeclarationRecords;
import com.ruoyi.jjh.declaration.entity.BmsTemplateRecord;
import com.ruoyi.jjh.declaration.entity.dto.BmsBrandingAwardAddDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsBrandingAwardUpdateDto;
import com.ruoyi.jjh.declaration.entity.vo.BmsBigStrongAwardQueryVo;
import com.ruoyi.jjh.declaration.entity.vo.DeclarationRecordsVo;
import com.ruoyi.jjh.declaration.mapper.BmsBrandingAwardMapper;
import com.ruoyi.jjh.declaration.service.*;
import com.ruoyi.jjh.ent.entity.JProject;
import com.ruoyi.jjh.ent.service.JProjectService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.time.Year;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 品牌打造奖补Service业务层处理
 * 
 * @author farben
 * @date 2023-08-25
 */
@Service
public class BmsBrandingAwardServiceImpl extends ServiceImpl<BmsBrandingAwardMapper,BmsBrandingAward> implements IBmsBrandingAwardService {

    @Autowired
    private ICommonService iCommonService;

    @Autowired
    private IBmsDeclarationRecordsService iBmsDeclarationRecordsService;
    @Resource
    private IBmsTemplateInfoService iBmsTemplateInfoService;
    @Resource
    private JProjectService jProjectService;

    @Resource
    private IBmsTemplateRecordService iBmsTemplateRecordService;
    /**
     * 查询品牌打造奖补
     * 
     * @param id 品牌打造奖补主键
     * @return 品牌打造奖补
     */
    @Override
    public BmsBrandingAward selectBmsBrandingAwardById(Long id) {
        return baseMapper.selectBmsBrandingAwardById(id);
    }

    /**
     * 查询品牌打造奖补列表
     * 
     * @param bmsBrandingAward 品牌打造奖补
     * @return 品牌打造奖补
     */
    @Override
    public List<BmsBrandingAward> selectBmsBrandingAwardList(BmsBrandingAward bmsBrandingAward) {
        return baseMapper.selectBmsBrandingAwardList(bmsBrandingAward);
    }

    /**
     * 新增品牌打造奖补
     * 
     * @param bmsBrandingAwardAddDto 品牌打造奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int insertBmsBrandingAward(BmsBrandingAwardAddDto bmsBrandingAwardAddDto) {
        Long enterpriseId = iCommonService.checkEnterprise(bmsBrandingAwardAddDto.getTyshxydm()
                ,bmsBrandingAwardAddDto.getTemplateRecordId());
        // check 申报信息
        iCommonService.checkDeclaration(bmsBrandingAwardAddDto.getTyshxydm()
                ,bmsBrandingAwardAddDto.getTemplateRecordId());
        BmsBrandingAward bmsBrandingAward = new BmsBrandingAward();
        BeanUtil.copyProperties(bmsBrandingAwardAddDto,bmsBrandingAward);
        bmsBrandingAward.setEnterpriseId(enterpriseId);
        // 新增做大做强奖详情
        int num = baseMapper.insert(bmsBrandingAward);

        // 新增申请记录
        BmsDeclarationRecords declarationRecords = new BmsDeclarationRecords();
        declarationRecords.setMatter("提交品牌打造奖补申请");
        declarationRecords.setDetailId(bmsBrandingAward.getId());
        declarationRecords.setId(bmsBrandingAwardAddDto.getDeclarationId());
        //如果该申报任务是不需要审批的则修改状态为已填报
        BmsTemplateRecord tes = iBmsTemplateRecordService.getById(iBmsDeclarationRecordsService.getById(bmsBrandingAwardAddDto.getDeclarationId()).getTemplateRecordId());
        if(tes.getIsApproval() == 0){
            declarationRecords.setStatus(6L);
            iBmsDeclarationRecordsService.updateById(declarationRecords);
        }else {
            iBmsDeclarationRecordsService.updateById(declarationRecords);
            declarationRecords.setStatus(1L);
            iBmsDeclarationRecordsService.updateById(declarationRecords);
            //获取某个在线记录id可以添加到项目库的数据
            JProject addProject = iBmsDeclarationRecordsService.getAddProject(bmsBrandingAwardAddDto.getDeclarationId());
            addProject.setStatus(1);
            addProject.setOtherJson(JSONObject.toJSONString(bmsBrandingAward));
            addProject.setFileJson("{" +
                    '"' + "证明材料" + '"' + ":" + '"' +bmsBrandingAward.getEvidence()+ '"' +
                    "}");
            jProjectService.save(addProject);
            declarationRecords.setJjhProjectId(addProject.getId());
            iBmsDeclarationRecordsService.updateById(declarationRecords);
            // 审批状态
            iCommonService.insertAuditRecord(declarationRecords.getId(),0);
        }
        return num;
    }

    /**
     * 修改品牌打造奖补
     * 
     * @param bmsBrandingAwardUpdateDto 品牌打造奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateBmsBrandingAward(BmsBrandingAwardUpdateDto bmsBrandingAwardUpdateDto) {
        int num = 0;
        try {
            BmsDeclarationRecords newRecord = new BmsDeclarationRecords();
            newRecord.setId(bmsBrandingAwardUpdateDto.getDeclarationRecordsId());
            newRecord.setStatus(bmsBrandingAwardUpdateDto.getStatus());
            iBmsDeclarationRecordsService.updateById(newRecord);

            bmsBrandingAwardUpdateDto.setUpdateTime(DateUtils.getNowDate());
            num = baseMapper.updateBmsBrandingAward(bmsBrandingAwardUpdateDto);
            // 申请审批
            if (bmsBrandingAwardUpdateDto.getStatus()==1){
                JProject jP = new JProject();
                BmsBrandingAward bmsBrandingAward =new BmsBrandingAward();
                BeanUtil.copyProperties(bmsBrandingAwardUpdateDto, bmsBrandingAward);
                jP.setId(iBmsDeclarationRecordsService.getById(bmsBrandingAwardUpdateDto.getDeclarationRecordsId()).getJjhProjectId());
                jP.setStatus(1);
                jP.setOtherJson(JSONObject.toJSONString(bmsBrandingAward));
                jP.setFileJson("{" +
                        '"' + "证明材料" + '"' + ":" + '"' + bmsBrandingAward.getEvidence() + '"' +
                        "}");
                //修改项目
                jProjectService.updateById(jP);
                // 审批状态
                iCommonService.updateAuditRecord(bmsBrandingAwardUpdateDto.getDeclarationRecordsId(), 0);
            }
        }catch (Exception e){
            e.printStackTrace();
        }
        return num;
    }

    /**
     * 批量删除品牌打造奖补
     * 
     * @param ids 需要删除的品牌打造奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsBrandingAwardByIds(Long[] ids) {
        return baseMapper.deleteBmsBrandingAwardByIds(ids);
    }

    /**
     * 删除品牌打造奖补信息
     * 
     * @param id 品牌打造奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsBrandingAwardById(Long id) {
        return baseMapper.deleteBmsBrandingAwardById(id);
    }
}
