package com.ruoyi.jjh.declaration.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.jjh.declaration.entity.BmsBrandingAward;
import com.ruoyi.jjh.declaration.entity.BmsCreditManagement;
import com.ruoyi.jjh.declaration.entity.BmsDeclarationRecords;
import com.ruoyi.jjh.declaration.entity.BmsTemplateRecord;
import com.ruoyi.jjh.declaration.entity.dto.BmsCreditManagementAddDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsCreditManagementUpdateDto;
import com.ruoyi.jjh.declaration.entity.vo.BmsBigStrongAwardQueryVo;
import com.ruoyi.jjh.declaration.entity.vo.DeclarationRecordsVo;
import com.ruoyi.jjh.declaration.mapper.BmsCreditManagementMapper;
import com.ruoyi.jjh.declaration.service.*;
import com.ruoyi.jjh.ent.entity.JProject;
import com.ruoyi.jjh.ent.service.JProjectService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.time.Year;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 信用管理奖补Service业务层处理
 * 
 * @author farben
 * @date 2023-09-04
 */
@Service
public class BmsCreditManagementServiceImpl extends ServiceImpl<BmsCreditManagementMapper,BmsCreditManagement> implements IBmsCreditManagementService {

    @Autowired
    private ICommonService iCommonService;

    @Autowired
    private IBmsDeclarationRecordsService iBmsDeclarationRecordsService;

    @Resource
    private IBmsTemplateInfoService iBmsTemplateInfoService;
    @Resource
    private JProjectService jProjectService;

    @Resource
    private IBmsTemplateRecordService iBmsTemplateRecordService;
    /**
     * 查询信用管理奖补
     * 
     * @param id 信用管理奖补主键
     * @return 信用管理奖补
     */
    @Override
    public BmsCreditManagement selectBmsCreditManagementById(Long id) {
        return baseMapper.selectBmsCreditManagementById(id);
    }

    /**
     * 查询信用管理奖补列表
     * 
     * @param bmsCreditManagement 信用管理奖补
     * @return 信用管理奖补
     */
    @Override
    public List<BmsCreditManagement> selectBmsCreditManagementList(BmsCreditManagement bmsCreditManagement) {
        return baseMapper.selectBmsCreditManagementList(bmsCreditManagement);
    }

    /**
     * 新增信用管理奖补
     * 
     * @param bmsCreditManagementAddDto 信用管理奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int insertBmsCreditManagement(BmsCreditManagementAddDto bmsCreditManagementAddDto) {
        Long enterpriseId = iCommonService.checkEnterprise(bmsCreditManagementAddDto.getTyshxydm()
                ,bmsCreditManagementAddDto.getTemplateRecordId());
        // check 申报信息
        iCommonService.checkDeclaration(bmsCreditManagementAddDto.getTyshxydm()
                ,bmsCreditManagementAddDto.getTemplateRecordId());
        BmsCreditManagement bmsCreditManagement = new BmsCreditManagement();
        BeanUtil.copyProperties(bmsCreditManagementAddDto,bmsCreditManagement);
        bmsCreditManagement.setEnterpriseId(enterpriseId);
        // 新增做大做强奖详情
        int num = baseMapper.insert(bmsCreditManagement);

        // 新增申请记录
        BmsDeclarationRecords declarationRecords = new BmsDeclarationRecords();
        declarationRecords.setMatter("提交信用管理奖补申请");
        declarationRecords.setDetailId(bmsCreditManagement.getId());
        declarationRecords.setId(bmsCreditManagementAddDto.getDeclarationId());
        //如果该申报任务是不需要审批的则修改状态为已填报
        BmsTemplateRecord tes = iBmsTemplateRecordService.getById(iBmsDeclarationRecordsService.getById(bmsCreditManagementAddDto.getDeclarationId()).getTemplateRecordId());
        if(tes.getIsApproval() == 0){
            declarationRecords.setStatus(6L);
            iBmsDeclarationRecordsService.updateById(declarationRecords);
        }else {
            declarationRecords.setStatus(1L);
            iBmsDeclarationRecordsService.updateById(declarationRecords);
            //获取某个在线记录id可以添加到项目库的数据
            JProject addProject = iBmsDeclarationRecordsService.getAddProject(bmsCreditManagementAddDto.getDeclarationId());
            addProject.setStatus(1);
            addProject.setOtherJson(JSONObject.toJSONString(bmsCreditManagement));
            addProject.setFileJson("{" +
                    '"' + "项目方案" + '"' + ":" + '"' + bmsCreditManagement.getProjectPlan() + '"' + ","+
                    '"' + "资金使用说明" + '"' + ":" + '"' + bmsCreditManagement.getUsesFunds() + '"' + ","+
                    '"' + "项目专项审计报告" + '"' + ":" + '"' + bmsCreditManagement.getAuditReport() + '"' +
                    "}");
            jProjectService.save(addProject);
            declarationRecords.setJjhProjectId(addProject.getId());
            iBmsDeclarationRecordsService.updateById(declarationRecords);

            // 生成审核
            iCommonService.insertAuditRecord(declarationRecords.getId(),0);
        }
        return num;
    }

    /**
     * 修改信用管理奖补
     * 
     * @param bmsCreditManagementUpdateDto 信用管理奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateBmsCreditManagement(BmsCreditManagementUpdateDto bmsCreditManagementUpdateDto) {
        int num = 0;
        try {
            BmsDeclarationRecords newRecord = new BmsDeclarationRecords();
            newRecord.setId(bmsCreditManagementUpdateDto.getDeclarationRecordsId());
            newRecord.setStatus(bmsCreditManagementUpdateDto.getStatus());
            iBmsDeclarationRecordsService.updateById(newRecord);

            bmsCreditManagementUpdateDto.setUpdateTime(DateUtils.getNowDate());
            num =  baseMapper.updateBmsCreditManagement(bmsCreditManagementUpdateDto);
            // 申请审批
            if (bmsCreditManagementUpdateDto.getStatus()==1){
                JProject jP = new JProject();
                BmsCreditManagement bmsCreditManagement =new BmsCreditManagement();
                BeanUtil.copyProperties(bmsCreditManagementUpdateDto, bmsCreditManagement);
                jP.setId(iBmsDeclarationRecordsService.getById(bmsCreditManagementUpdateDto.getDeclarationRecordsId()).getJjhProjectId());
                jP.setStatus(1);
                jP.setOtherJson(JSONObject.toJSONString(bmsCreditManagement));
                jP.setFileJson("{" +
                        '"' + "项目方案" + '"' + ":" + '"' + bmsCreditManagement.getProjectPlan() + '"' + ","+
                        '"' + "资金使用说明" + '"' + ":" + '"' + bmsCreditManagement.getUsesFunds() + '"' + ","+
                        '"' + "项目专项审计报告" + '"' + ":" + '"' + bmsCreditManagement.getAuditReport() + '"' +
                        "}");
                //修改项目
                jProjectService.updateById(jP);
                // 审批状态
                iCommonService.updateAuditRecord(bmsCreditManagementUpdateDto.getDeclarationRecordsId(), 0);
            }
        }catch (Exception e){
            e.printStackTrace();
        }
        return num;
    }

    /**
     * 批量删除信用管理奖补
     * 
     * @param ids 需要删除的信用管理奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsCreditManagementByIds(Long[] ids) {
        return baseMapper.deleteBmsCreditManagementByIds(ids);
    }

    /**
     * 删除信用管理奖补信息
     * 
     * @param id 信用管理奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsCreditManagementById(Long id) {
        return baseMapper.deleteBmsCreditManagementById(id);
    }
}
