package com.ruoyi.jjh.declaration.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.jjh.declaration.entity.*;
import com.ruoyi.jjh.declaration.entity.dto.BmsIntegrationIndustriesAddDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsIntegrationIndustriesUpdateDto;
import com.ruoyi.jjh.declaration.entity.vo.DeclarationRecordsVo;
import com.ruoyi.jjh.declaration.mapper.BmsIntegrationIndustriesMapper;
import com.ruoyi.jjh.declaration.service.*;
import com.ruoyi.jjh.ent.entity.JProject;
import com.ruoyi.jjh.ent.service.JProjectService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.time.Year;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 两业融合奖补Service业务层处理
 * 
 * @author farben
 * @date 2023-09-04
 */
@Service
public class BmsIntegrationIndustriesServiceImpl extends ServiceImpl<BmsIntegrationIndustriesMapper,BmsIntegrationIndustries> implements IBmsIntegrationIndustriesService {

    @Autowired
    private ICommonService iCommonService;
    @Resource
    private IBmsTemplateInfoService iBmsTemplateInfoService;
    @Autowired
    private IBmsDeclarationRecordsService iBmsDeclarationRecordsService;

    @Resource
    private JProjectService jProjectService;

    @Resource
    private IBmsTemplateRecordService iBmsTemplateRecordService;
    /**
     * 查询两业融合奖补
     * 
     * @param id 两业融合奖补主键
     * @return 两业融合奖补
     */
    @Override
    public BmsIntegrationIndustries selectBmsIntegrationIndustriesById(Long id) {
        return baseMapper.selectBmsIntegrationIndustriesById(id);
    }

    /**
     * 查询两业融合奖补列表
     * 
     * @param bmsIntegrationIndustries 两业融合奖补
     * @return 两业融合奖补
     */
    @Override
    public List<BmsIntegrationIndustries> selectBmsIntegrationIndustriesList(BmsIntegrationIndustries bmsIntegrationIndustries) {
        return baseMapper.selectBmsIntegrationIndustriesList(bmsIntegrationIndustries);
    }

    /**
     * 新增两业融合奖补
     * 
     * @param bmsIntegrationIndustriesAddDto 两业融合奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int insertBmsIntegrationIndustries(BmsIntegrationIndustriesAddDto bmsIntegrationIndustriesAddDto) {
        Long enterpriseId = iCommonService.checkEnterprise(bmsIntegrationIndustriesAddDto.getTyshxydm()
                ,bmsIntegrationIndustriesAddDto.getTemplateRecordId());
        // check 申报信息
        iCommonService.checkDeclaration(bmsIntegrationIndustriesAddDto.getTyshxydm()
                ,bmsIntegrationIndustriesAddDto.getTemplateRecordId());
        BmsIntegrationIndustries bmsIntegrationIndustries = new BmsIntegrationIndustries();
        BeanUtil.copyProperties(bmsIntegrationIndustriesAddDto,bmsIntegrationIndustries);
        bmsIntegrationIndustries.setEnterpriseId(enterpriseId);
        // 新增做大做强奖详情
        int num = baseMapper.insert(bmsIntegrationIndustries);

        // 新增申请记录
        BmsDeclarationRecords declarationRecords = new BmsDeclarationRecords();
        declarationRecords.setMatter("提交两业融合奖补申请");
        declarationRecords.setDetailId(bmsIntegrationIndustries.getId());
        declarationRecords.setId(bmsIntegrationIndustriesAddDto.getDeclarationId());
        //如果该申报任务是不需要审批的则修改状态为已填报
        BmsTemplateRecord tes = iBmsTemplateRecordService.getById(iBmsDeclarationRecordsService.getById(bmsIntegrationIndustriesAddDto.getDeclarationId()).getTemplateRecordId());
        if(tes.getIsApproval() == 0){
            declarationRecords.setStatus(6L);
            iBmsDeclarationRecordsService.updateById(declarationRecords);
        }else {
            declarationRecords.setStatus(1L);
            iBmsDeclarationRecordsService.updateById(declarationRecords);
            //获取某个在线记录id可以添加到项目库的数据
            JProject addProject = iBmsDeclarationRecordsService.getAddProject(bmsIntegrationIndustriesAddDto.getDeclarationId());
            addProject.setStatus(1);
            if(bmsIntegrationIndustries.getDeclarationType() == 1){
                bmsIntegrationIndustries.setNewDeclarationType("两业融合示范企业");
            }else if(bmsIntegrationIndustries.getDeclarationType() == 2){
                bmsIntegrationIndustries.setNewDeclarationType("制造业企业设立财务独立核算的制造服务业职能部门");
            }else if(bmsIntegrationIndustries.getDeclarationType() == 3){
                bmsIntegrationIndustries.setNewDeclarationType("制造业企业剥离服务业务成立独立的法人");
            }
            addProject.setOtherJson(JSONObject.toJSONString(bmsIntegrationIndustries));
            addProject.setFileJson("{" +
                    '"' + "证明材料" + '"' + ":" + '"' + bmsIntegrationIndustries.getEvidence() + '"' + ","+
                    '"' + "营业执照" + '"' + ":" + '"' + bmsIntegrationIndustries.getBusinessLicense() + '"' + ","+
                    '"' + "完税证明" + '"' + ":" + '"' + bmsIntegrationIndustries.getTaxPaymentCertificate() + '"' + ","+
                    '"' + "审计报告" + '"' + ":" + '"' + bmsIntegrationIndustries.getAuditReport() + '"' + ","+
                    '"' + "股权架构图" + '"' + ":" + '"' + bmsIntegrationIndustries.getEquityStructureChart() + '"' + ","+
                    '"' + "项目申报报告" + '"' + ":" + '"' + bmsIntegrationIndustries.getDeclarationReport() + '"' + ","+
                    '"' + "独立核算相关证明" + '"' + ":" + '"' + bmsIntegrationIndustries.getIndependentAccounting() + '"' + ","+
                    '"' + "验资报告" + '"' + ":" + '"' + bmsIntegrationIndustries.getCapitalVerificationReport()+ '"' + ","+
                    '"' + "其他证明材料" + '"' + ":" + '"' + bmsIntegrationIndustries.getOtherEvidence() + '"' +
                    "}");
            jProjectService.save(addProject);
            declarationRecords.setJjhProjectId(addProject.getId());
            iBmsDeclarationRecordsService.updateById(declarationRecords);
            // 生成审核
            iCommonService.insertAuditRecord(declarationRecords.getId(),0);
        }
        return num;
    }

    /**
     * 修改两业融合奖补
     * 
     * @param bmsIntegrationIndustriesUpdateDto 两业融合奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateBmsIntegrationIndustries(BmsIntegrationIndustriesUpdateDto bmsIntegrationIndustriesUpdateDto) {
        int num = 0;
        try {
            BmsDeclarationRecords newRecord = new BmsDeclarationRecords();
            newRecord.setId(bmsIntegrationIndustriesUpdateDto.getDeclarationRecordsId());
            newRecord.setStatus(bmsIntegrationIndustriesUpdateDto.getStatus());
            iBmsDeclarationRecordsService.updateById(newRecord);

            bmsIntegrationIndustriesUpdateDto.setUpdateTime(DateUtils.getNowDate());
            num = baseMapper.updateBmsIntegrationIndustries(bmsIntegrationIndustriesUpdateDto);
            // 申请审批
            if (bmsIntegrationIndustriesUpdateDto.getStatus()==1){
                JProject jP = new JProject();
                BmsIntegrationIndustries p1 =new BmsIntegrationIndustries();
                BeanUtil.copyProperties(bmsIntegrationIndustriesUpdateDto, p1);
                jP.setId(iBmsDeclarationRecordsService.getById(bmsIntegrationIndustriesUpdateDto.getDeclarationRecordsId()).getJjhProjectId());
                jP.setStatus(1);
                jP.setOtherJson(JSONObject.toJSONString(p1));
                jP.setFileJson("{" +
                        '"' + "证明材料" + '"' + ":" + '"' + p1.getEvidence() + '"' + ","+
                        '"' + "营业执照" + '"' + ":" + '"' + p1.getBusinessLicense() + '"' + ","+
                        '"' + "完税证明" + '"' + ":" + '"' + p1.getTaxPaymentCertificate() + '"' + ","+
                        '"' + "审计报告" + '"' + ":" + '"' + p1.getAuditReport() + '"' + ","+
                        '"' + "股权架构图" + '"' + ":" + '"' + p1.getEquityStructureChart() + '"' + ","+
                        '"' + "项目申报报告" + '"' + ":" + '"' + p1.getDeclarationReport() + '"' + ","+
                        '"' + "独立核算相关证明" + '"' + ":" + '"' + p1.getIndependentAccounting() + '"' + ","+
                        '"' + "验资报告" + '"' + ":" + '"' + p1.getCapitalVerificationReport()+ '"' + ","+
                        '"' + "其他证明材料" + '"' + ":" + '"' + p1.getOtherEvidence() + '"' +
                        "}");
                //修改项目
                jProjectService.updateById(jP);
                // 审批状态
                iCommonService.updateAuditRecord(bmsIntegrationIndustriesUpdateDto.getDeclarationRecordsId(), 0);
            }
        }catch (Exception e){
            e.printStackTrace();
        }
        bmsIntegrationIndustriesUpdateDto.setUpdateTime(DateUtils.getNowDate());
        return num;
    }

    /**
     * 批量删除两业融合奖补
     * 
     * @param ids 需要删除的两业融合奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsIntegrationIndustriesByIds(Long[] ids) {
        return baseMapper.deleteBmsIntegrationIndustriesByIds(ids);
    }

    /**
     * 删除两业融合奖补信息
     * 
     * @param id 两业融合奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsIntegrationIndustriesById(Long id) {
        return baseMapper.deleteBmsIntegrationIndustriesById(id);
    }
}
