package com.ruoyi.jjh.declaration.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.jjh.declaration.entity.*;
import com.ruoyi.jjh.declaration.entity.dto.BmsPlatformConstructionAwardAddDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsPlatformConstructionAwardUpdateDto;
import com.ruoyi.jjh.declaration.entity.vo.DeclarationRecordsVo;
import com.ruoyi.jjh.declaration.mapper.BmsPlatformConstructionAwardMapper;
import com.ruoyi.jjh.declaration.service.*;
import com.ruoyi.jjh.ent.entity.JProject;
import com.ruoyi.jjh.ent.service.JProjectService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.time.Year;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 平台建设奖补Service业务层处理
 * 
 * @author farben
 * @date 2023-08-25
 */
@Service
@Lazy
public class BmsPlatformConstructionAwardServiceImpl extends ServiceImpl<BmsPlatformConstructionAwardMapper,BmsPlatformConstructionAward> implements IBmsPlatformConstructionAwardService {

    @Autowired
    private ICommonService iCommonService;

    @Autowired
    private IBmsDeclarationRecordsService iBmsDeclarationRecordsService;
    @Resource
    private IBmsTemplateInfoService iBmsTemplateInfoService;
    @Resource
    private JProjectService jProjectService;
    @Resource
    private IBmsTemplateRecordService iBmsTemplateRecordService;
    /**
     * 查询平台建设奖补
     * 
     * @param id 平台建设奖补主键
     * @return 平台建设奖补
     */
    @Override
    public BmsPlatformConstructionAward selectBmsPlatformConstructionAwardById(Long id) {
        return baseMapper.selectBmsPlatformConstructionAwardById(id);
    }

    /**
     * 查询平台建设奖补列表
     * 
     * @param bmsPlatformConstructionAward 平台建设奖补
     * @return 平台建设奖补
     */
    @Override
    public List<BmsPlatformConstructionAward> selectBmsPlatformConstructionAwardList(BmsPlatformConstructionAward bmsPlatformConstructionAward) {
        return baseMapper.selectBmsPlatformConstructionAwardList(bmsPlatformConstructionAward);
    }

    /**
     * 新增平台建设奖补
     * 
     * @param bmsPlatformConstructionAwardAddDto 平台建设奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int insertBmsPlatformConstructionAward(BmsPlatformConstructionAwardAddDto bmsPlatformConstructionAwardAddDto) {
        Long enterpriseId = iCommonService.checkEnterprise(bmsPlatformConstructionAwardAddDto.getTyshxydm()
                ,bmsPlatformConstructionAwardAddDto.getTemplateRecordId());
        // check 申报信息
        iCommonService.checkDeclaration(bmsPlatformConstructionAwardAddDto.getTyshxydm()
                ,bmsPlatformConstructionAwardAddDto.getTemplateRecordId());
        BmsPlatformConstructionAward bmsPlatformConstructionAward = new BmsPlatformConstructionAward();
        BeanUtil.copyProperties(bmsPlatformConstructionAwardAddDto,bmsPlatformConstructionAward);
        bmsPlatformConstructionAward.setEnterpriseId(enterpriseId);
        // 新增做大做强奖详情
        int num = baseMapper.insert(bmsPlatformConstructionAward);

        // 新增申请记录
        BmsDeclarationRecords declarationRecords = new BmsDeclarationRecords();
        declarationRecords.setMatter("提交平台建设奖补申请");
        declarationRecords.setId(bmsPlatformConstructionAwardAddDto.getDeclarationId());
        declarationRecords.setDetailId(bmsPlatformConstructionAward.getId());
        //如果该申报任务是不需要审批的则修改状态为已填报
        BmsTemplateRecord tes = iBmsTemplateRecordService.getById(iBmsDeclarationRecordsService.getById(bmsPlatformConstructionAwardAddDto.getDeclarationId()).getTemplateRecordId());
        if(tes.getIsApproval() == 0){
            declarationRecords.setStatus(6L);
            iBmsDeclarationRecordsService.updateById(declarationRecords);
        }else {
            declarationRecords.setStatus(1L);
            iBmsDeclarationRecordsService.updateById(declarationRecords);

            //获取某个在线记录id可以添加到项目库的数据
            JProject addProject = iBmsDeclarationRecordsService.getAddProject(bmsPlatformConstructionAwardAddDto.getDeclarationId());
            addProject.setStatus(1);
            addProject.setOtherJson(JSONObject.toJSONString(bmsPlatformConstructionAward));
            addProject.setFileJson( "{" +
                    '"' + "合作协议" + '"' + ":" + '"' + bmsPlatformConstructionAward.getAgreement() + '"' +
                    "}");
            jProjectService.save(addProject);
            declarationRecords.setJjhProjectId(addProject.getId());
            iBmsDeclarationRecordsService.updateById(declarationRecords);

            // 生成审核
            iCommonService.insertAuditRecord(declarationRecords.getId(),0);
        }
        return num;
    }


    /**
     * 修改平台建设奖补
     * 
     * @param bmsPlatformConstructionAwardUpdateDto 平台建设奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateBmsPlatformConstructionAward(BmsPlatformConstructionAwardUpdateDto bmsPlatformConstructionAwardUpdateDto) {
        int num = 0;
        try {
            BmsDeclarationRecords newRecord = new BmsDeclarationRecords();
            newRecord.setId(bmsPlatformConstructionAwardUpdateDto.getDeclarationRecordsId());
            newRecord.setStatus(bmsPlatformConstructionAwardUpdateDto.getStatus());
            iBmsDeclarationRecordsService.updateById(newRecord);

            num = baseMapper.updateBmsPlatformConstructionAward(bmsPlatformConstructionAwardUpdateDto);
            // 申请审批
            if (bmsPlatformConstructionAwardUpdateDto.getStatus()==1){
                JProject jP = new JProject();
                BmsPlatformConstructionAward p1 =new BmsPlatformConstructionAward();
                BeanUtil.copyProperties(bmsPlatformConstructionAwardUpdateDto, p1);
                jP.setId(iBmsDeclarationRecordsService.getById(bmsPlatformConstructionAwardUpdateDto.getDeclarationRecordsId()).getJjhProjectId());
                jP.setStatus(1);
                jP.setOtherJson(JSONObject.toJSONString(p1));
                jP.setFileJson("{" +
                        '"' + "合作协议" + '"' + ":" + '"' + p1.getAgreement() + '"' +
                        "}");
                //修改项目
                jProjectService.updateById(jP);
                // 审批状态
                iCommonService.updateAuditRecord(bmsPlatformConstructionAwardUpdateDto.getDeclarationRecordsId(), 0);
            }
        }catch (Exception e){
            e.printStackTrace();
        }
        return num;
    }

    /**
     * 批量删除平台建设奖补
     * 
     * @param ids 需要删除的平台建设奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsPlatformConstructionAwardByIds(Long[] ids) {
        return baseMapper.deleteBmsPlatformConstructionAwardByIds(ids);
    }

    /**
     * 删除平台建设奖补信息
     * 
     * @param id 平台建设奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsPlatformConstructionAwardById(Long id) {
        return baseMapper.deleteBmsPlatformConstructionAwardById(id);
    }
}
