package com.ruoyi.jjh.declaration.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.jjh.declaration.entity.BmsDeclarationRecords;
import com.ruoyi.jjh.declaration.entity.BmsIndustrialInternetAward;
import com.ruoyi.jjh.declaration.entity.BmsSceneOpeningAward;
import com.ruoyi.jjh.declaration.entity.BmsTemplateRecord;
import com.ruoyi.jjh.declaration.entity.dto.BmsSceneOpeningAwardAddDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsSceneOpeningAwardUpdateDto;
import com.ruoyi.jjh.declaration.entity.vo.BmsBigStrongAwardQueryVo;
import com.ruoyi.jjh.declaration.entity.vo.DeclarationRecordsVo;
import com.ruoyi.jjh.declaration.mapper.BmsSceneOpeningAwardMapper;
import com.ruoyi.jjh.declaration.service.*;
import com.ruoyi.jjh.ent.entity.JProject;
import com.ruoyi.jjh.ent.service.JProjectService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.time.Year;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 场景开放奖补Service业务层处理
 * 
 * @author farben
 * @date 2023-08-25
 */
@Service
public class BmsSceneOpeningAwardServiceImpl extends ServiceImpl<BmsSceneOpeningAwardMapper,BmsSceneOpeningAward> implements IBmsSceneOpeningAwardService {

    @Autowired
    private ICommonService iCommonService;

    @Autowired
    private IBmsDeclarationRecordsService iBmsDeclarationRecordsService;

    @Resource
    private JProjectService jProjectService;

    @Resource
    private IBmsTemplateInfoService iBmsTemplateInfoService;

    @Resource
    private IBmsTemplateRecordService iBmsTemplateRecordService;
    /**
     * 查询场景开放奖补
     * 
     * @param id 场景开放奖补主键
     * @return 场景开放奖补
     */
    @Override
    public BmsSceneOpeningAward selectBmsSceneOpeningAwardById(Long id) {
        return baseMapper.selectBmsSceneOpeningAwardById(id);
    }

    /**
     * 查询场景开放奖补列表
     * 
     * @param bmsSceneOpeningAward 场景开放奖补
     * @return 场景开放奖补
     */
    @Override
    public List<BmsSceneOpeningAward> selectBmsSceneOpeningAwardList(BmsSceneOpeningAward bmsSceneOpeningAward) {
        return baseMapper.selectBmsSceneOpeningAwardList(bmsSceneOpeningAward);
    }

    /**
     * 新增场景开放奖补
     * 
     * @param bmsSceneOpeningAwardAddDto 场景开放奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int insertBmsSceneOpeningAward(BmsSceneOpeningAwardAddDto bmsSceneOpeningAwardAddDto) {
        Long enterpriseId = iCommonService.checkEnterprise(bmsSceneOpeningAwardAddDto.getTyshxydm()
                ,bmsSceneOpeningAwardAddDto.getTemplateRecordId());
        // check 申报信息
        iCommonService.checkDeclaration(bmsSceneOpeningAwardAddDto.getTyshxydm()
                ,bmsSceneOpeningAwardAddDto.getTemplateRecordId());
        BmsSceneOpeningAward bmsSceneOpeningAward = new BmsSceneOpeningAward();
        BeanUtil.copyProperties(bmsSceneOpeningAwardAddDto,bmsSceneOpeningAward);
        bmsSceneOpeningAward.setEnterpriseId(enterpriseId);
        // 新增做大做强奖详情
        int num = baseMapper.insert(bmsSceneOpeningAward);


        BmsDeclarationRecords declarationRecords = new BmsDeclarationRecords();
        declarationRecords.setMatter("提交场景开放奖补申请");
        declarationRecords.setDetailId(bmsSceneOpeningAward.getId());
        declarationRecords.setId(bmsSceneOpeningAwardAddDto.getDeclarationId());

        //如果该申报任务是不需要审批的则修改状态为已填报
        BmsTemplateRecord tes = iBmsTemplateRecordService.getById(iBmsDeclarationRecordsService.getById(bmsSceneOpeningAwardAddDto.getDeclarationId()).getTemplateRecordId());
        if(tes.getIsApproval() == 0){
            declarationRecords.setStatus(6L);
            iBmsDeclarationRecordsService.updateById(declarationRecords);
        }else {
            declarationRecords.setStatus(1L);
            iBmsDeclarationRecordsService.updateById(declarationRecords);
            //获取某个在线记录id可以添加到项目库的数据
            JProject addProject = iBmsDeclarationRecordsService.getAddProject(bmsSceneOpeningAwardAddDto.getDeclarationId());
            addProject.setStatus(1);
            if(bmsSceneOpeningAward.getType() == 0){
                bmsSceneOpeningAward.setNewType("市场服务类");
            }else{
                bmsSceneOpeningAward.setNewType("公共服务类");
            }
            addProject.setOtherJson(JSONObject.toJSONString(bmsSceneOpeningAward));
            addProject.setFileJson("{" +
                    '"' + "证明材料(公示、发文证明、专家评分表)" + '"' + ":" + '"' + bmsSceneOpeningAward.getMaterial() + '"' +
                    "}");
            jProjectService.save(addProject);
            declarationRecords.setJjhProjectId(addProject.getId());
            iBmsDeclarationRecordsService.updateById(declarationRecords);

            // 生成审核
            iCommonService.insertAuditRecord(declarationRecords.getId(),0);
        }
        return num;
    }

    /**
     * 修改场景开放奖补
     * 
     * @param bmsSceneOpeningAwardUpdateDto 场景开放奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateBmsSceneOpeningAward(BmsSceneOpeningAwardUpdateDto bmsSceneOpeningAwardUpdateDto) {
        int num = 0;
        try {
            BmsDeclarationRecords newRecord = new BmsDeclarationRecords();
            newRecord.setId(bmsSceneOpeningAwardUpdateDto.getDeclarationRecordsId());
            newRecord.setStatus(bmsSceneOpeningAwardUpdateDto.getStatus());
            iBmsDeclarationRecordsService.updateById(newRecord);

            bmsSceneOpeningAwardUpdateDto.setUpdateTime(DateUtils.getNowDate());
            num=baseMapper.updateBmsSceneOpeningAward(bmsSceneOpeningAwardUpdateDto);
            // 申请审批
            if (bmsSceneOpeningAwardUpdateDto.getStatus()==1){
                JProject jP = new JProject();
                BmsSceneOpeningAward bs =new BmsSceneOpeningAward();
                BeanUtil.copyProperties(bmsSceneOpeningAwardUpdateDto, bs);
                jP.setId(iBmsDeclarationRecordsService.getById(bmsSceneOpeningAwardUpdateDto.getDeclarationRecordsId()).getJjhProjectId());
                jP.setStatus(1);
                jP.setOtherJson(JSONObject.toJSONString(bs));
                jP.setFileJson( "{" +
                        '"' + "证明材料(公示、发文证明、专家评分表)" + '"' + ":" + '"' + bs.getMaterial() + '"' +
                        "}");
                //修改项目
                jProjectService.updateById(jP);
                // 审批状态
                iCommonService.updateAuditRecord(bmsSceneOpeningAwardUpdateDto.getDeclarationRecordsId(), 0);
            }
        }catch (Exception e){
            e.printStackTrace();
        }
        return num;
    }

    /**
     * 批量删除场景开放奖补
     * 
     * @param ids 需要删除的场景开放奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsSceneOpeningAwardByIds(Long[] ids) {
        return baseMapper.deleteBmsSceneOpeningAwardByIds(ids);
    }

    /**
     * 删除场景开放奖补信息
     * 
     * @param id 场景开放奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsSceneOpeningAwardById(Long id) {
        return baseMapper.deleteBmsSceneOpeningAwardById(id);
    }
}
