package com.ruoyi.jjh.ent.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.alibaba.fastjson2.JSONObject;
import com.ruoyi.jjh.ent.entity.JProject;
import com.ruoyi.jjh.ent.entity.response.*;
import com.ruoyi.jjh.ent.mapper.JDataScreenMapper;
import com.ruoyi.jjh.ent.service.JDataScreenService;
import com.ruoyi.jjh.ent.service.JProjectService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.*;

import static java.util.stream.Collectors.collectingAndThen;
import static java.util.stream.Collectors.toCollection;

/**
 * 数据大屏业务处理层
 *
 * @author du
 * @since 2024/5/13 9:58
 */
@Service
public class JDataScreenImpl implements JDataScreenService {

    @Resource
    private JDataScreenMapper jDataScreenMapper;

    @Resource
    private JProjectService jProjectService;


    /**
     * 荣誉情况
     *
     * @return 所有数据
     */
    @Override
    public List<HonorResponse> getHonor() {
        int x = 0;
        for (JProject jp : jProjectService.lambdaQuery().eq(JProject::getProjectMiddleType, 4).list()) {
            if ("否".equals(JSONObject.parseObject(jp.getOtherJson()).get("是否通过2022年度“331”评价"))) {
                x += 1;
            }
        }
        List<HonorResponse> honor = jDataScreenMapper.getHonor();
        for (HonorResponse y : honor) {
            if (y.getProjectBigType() == 4) {
                y.setCount1(y.getCount1() - x);
            }
            if (y.getProjectMiddleType() == 4) {
                y.setCount2(y.getCount2() - x);
            }
            if (y.getProjectSmallType() == 6) {
                y.setCount3(y.getCount3() - x);
            }
        }
        return honor;
    }

    /**
     * 项目追踪情况
     *
     * @return 所有数据
     */
    @Override
    public List<ProjectTrackingResponse> getProjectTracking() {
        return jDataScreenMapper.getProjectTracking();
    }

    /**
     * 服务业发展总览
     *
     * @return 所有数据
     */
    @Override
    public List<JServicesDevelopResponse> servicesDevelop(Integer type) {
        return jDataScreenMapper.servicesDevelop(type);
    }

    /**
     * 行业纵深情况
     *
     * @return 所有数据
     */
    @Override
    public List<JIndustryDepthResponse> getIndustryDepth() {
        List<JIndustryDepthResponse> list = jDataScreenMapper.getIndustryDepth();
        list.forEach(x -> {
            x.setYearRevenue(x.getYearRevenue() / 10000.0);
            x.setAddValue(x.getAddValue() / 10000.0);
        });
        return list;
    }

    /**
     * 所有分行业汇总
     *
     * @return 所有数据
     */
    @Override
    public List<JAllIndustryResponse> getAllIndustry() {
        //获取中类数据
        List<JBigMiddleIndustryResponse> list2 = jDataScreenMapper.getMiddleIndustry();
        //获取大类数据
        List<JAllIndustryResponse> all = jDataScreenMapper.getBigIndustry();
        // 向每个 JAllIndustryResponse 对象的 children 字段中添加数据
        all.forEach(allResponse -> {
            List<JAllIndustryResponse> children = new ArrayList<>();
            list2.forEach(middleResponse -> {
                if (allResponse.getNameType().equals(middleResponse.getCategories())) {
                    JAllIndustryResponse child = new JAllIndustryResponse();
                    BeanUtil.copyProperties(middleResponse, child);
                    children.add(child);
                }
            });
            allResponse.setChildren(children);
        });
        return all;
    }
}
